__version__ = "0.8.14"

__title__ = "joulescope"
__description__ = 'Joulescope™ host driver and utilities'
__url__ = 'https://joulescope.readthedocs.io'
__author__ = 'Jetperch LLC'
__author_email__ = 'joulescope-dev@jetperch.com'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2018-2020 Jetperch LLC'

